@@ -3,7 +3,7 @@
     This file is part of Kitlist, a program to maintain a simple list
     of items and assign items to one or more categories.
 
-    Copyright (C) 2008,2009 Frank Dean
+    Copyright (C) 2008-2021 Frank Dean
 
     Kitlist is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,15 +24,9 @@
 #include <locale.h>
 #include <iostream>
 #include <getopt.h>
-#ifdef MAEMO
-#include <locale.h>
-#endif
 #ifndef WIN32
 #include <libintl.h>
 #endif
-#ifdef MAEMO
-#include <syslog.h>
-#endif
 #include "kitlistgui.hpp"
 #include "kitlistpgsqldao.hpp"
 #include "xmldao.hpp"
@@ -44,9 +38,10 @@
  * The kitlist program has been developed to be run on multiple
  * platforms.  It is known to run on the following platforms:
  *
- *    - Debian 5.0 (Lenny)
- *    - Maemo (Nokia Tablet)
- *    - Windows XP
+ *    - Debian versions 5 (Lenny) through to 10 (Buster)
+ *    - macOS 11.3 (Big Sur) and many previous versions via
+ *      https://macports.org/
+ *    - Windows XP (but no longer supported)
  *
  * It can be compiled to use either a PostgreSQL database or XML
  * documents as the data store (Debian Linux only).  When compiled to
